Crate chimera_opencode

Crate chimera_opencode 

Structs

OpenCodeBackend
OpenCodeConfig
OpenCodeConfigBuilder
Use builder syntax to set the inputs and finish with build().
OpenCodeMcpServer
A single MCP server to register with the OpenCode agent.
OpenCodeMcpServerBuilder
Use builder syntax to set the inputs and finish with build().

Enums

OpenCodeExecutionMode
Selects whether Chimera calls an OpenAI-compatible endpoint directly or drives the installed OpenCode agent.
OpenCodeProvider
OpenCode API provider.
OpenCodeSession
Public session type – dispatches between HTTP (direct API) and Agent (subprocess) modes.