Structs
- Open
Code Backend - Open
Code Config - Open
Code Config Builder - Use builder syntax to set the inputs and finish with
build(). - Open
Code McpServer - A single MCP server to register with the OpenCode agent.
- Open
Code McpServer Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- Open
Code Execution Mode - Selects whether Chimera calls an OpenAI-compatible endpoint directly or drives the installed OpenCode agent.
- Open
Code Provider - OpenCode API provider.
- Open
Code Session - Public session type – dispatches between HTTP (direct API) and Agent (subprocess) modes.